@@ -524,7 +524,7 @@ class ElucidatedImagen(nn.Module):
                     lowres_noise_times = self.lowres_noise_schedule.get_times(batch_size, lowres_sample_noise_level, device = device)
 
                     lowres_cond_img = resize_image_to(img, image_size)
-                    lowres_cond_img = maybe(self.normalize_img)(lowres_cond_img)
+                    lowres_cond_img = self.normalize_img(lowres_cond_img)
 
                     lowres_cond_img, _ = self.lowres_noise_schedule.q_sample(x_start = lowres_cond_img, t = lowres_noise_times, noise = torch.randn_like(lowres_cond_img))
 
