@@ -275,9 +275,8 @@ class GaussianDiffusionContinuousTimes(nn.Module):
 # norms and residuals
 
 class LayerNorm(nn.Module):
-    def __init__(self, dim, eps = 1e-5, stable = False):
+    def __init__(self, dim, stable = False):
         super().__init__()
-        self.eps = eps
         self.stable = stable
         self.g = nn.Parameter(torch.ones(dim))
 
@@ -285,14 +284,14 @@ class LayerNorm(nn.Module):
         if self.stable:
             x = x / x.amax(dim = -1, keepdim = True).detach()
 
+        eps = 1e-5 if x.dtype == torch.float32 else 1e-3
         var = torch.var(x, dim = -1, unbiased = False, keepdim = True)
         mean = torch.mean(x, dim = -1, keepdim = True)
-        return (x - mean) * (var + self.eps).rsqrt() * self.g
+        return (x - mean) * (var + eps).rsqrt() * self.g
 
 class ChanLayerNorm(nn.Module):
-    def __init__(self, dim, eps = 1e-5, stable = False):
+    def __init__(self, dim, stable = False):
         super().__init__()
-        self.eps = eps
         self.stable = stable
         self.g = nn.Parameter(torch.ones(1, dim, 1, 1))
 
@@ -300,9 +299,10 @@ class ChanLayerNorm(nn.Module):
         if self.stable:
             x = x / x.amax(dim = 1, keepdim = True).detach()
 
+        eps = 1e-5 if x.dtype == torch.float32 else 1e-3
         var = torch.var(x, dim = 1, unbiased = False, keepdim = True)
         mean = torch.mean(x, dim = 1, keepdim = True)
-        return (x - mean) / (var + self.eps).sqrt() * self.g
+        return (x - mean) * (var + eps).rsqrt() * self.g
 
 class Always():
     def __init__(self, val):
@@ -2001,7 +2001,6 @@ class Imagen(nn.Module):
 
         batch = shape[0]
         img = torch.randn(shape, device = device)
-        lowres_cond_img = maybe(self.normalize_img)(lowres_cond_img)
 
         # prepare inpainting
 
@@ -2127,6 +2126,8 @@ class Imagen(nn.Module):
                     lowres_noise_times = self.lowres_noise_schedule.get_times(batch_size, lowres_sample_noise_level, device = device)
 
                     lowres_cond_img = resize_image_to(img, image_size)
+
+                    lowres_cond_img = self.normalize_img(lowres_cond_img)
                     lowres_cond_img, _ = self.lowres_noise_schedule.q_sample(x_start = lowres_cond_img, t = lowres_noise_times, noise = torch.randn_like(lowres_cond_img))
 
                 shape = (batch_size, self.channels, image_size, image_size)
